@@ -1,7 +1,7 @@
 package Perinci::Sub::Complete;
 
-our $DATE = '2019-06-29'; # DATE
-our $VERSION = '0.937'; # VERSION
+our $DATE = '2019-07-06'; # DATE
+our $VERSION = '0.938'; # VERSION
 
 use 5.010001;
 use strict;
@@ -177,6 +177,16 @@ sub complete_from_schema {
             $static++;
             return; # from eval. there should not be any other value
         }
+        if ($cs->{'x.examples'}) {
+            log_trace("[comp][periscomp] adding completion from schema's 'x.examples' attribute");
+            for my $i (0..$#{ $cs->{'x.examples'} }) {
+                next if ref $cs->{'x.examples'}[$i];
+                push @$words    , $cs->{'x.examples'}[$i];
+                push @$summaries, $cs->{'x.examples.summaries'} ? $cs->{'x.examples.summaries'}[$i] : undef;
+            }
+            $static++;
+            return; # from eval. there should not be any other value
+        }
         if ($type eq 'any') {
             # because currently Data::Sah::Normalize doesn't recursively
             # normalize schemas in 'of' clauses, etc.
@@ -1318,7 +1328,7 @@ Perinci::Sub::Complete - Complete command-line argument using Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.937 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2019-06-29.
+This document describes version 0.938 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2019-07-06.
 
 =head1 SYNOPSIS
 
